@@ -29,6 +29,8 @@
 #define FORS_BIAS_IMPL_H
 
 #include <cpl.h>
+#include <fors_image.h>
+#include <fors_stack.h>
 
 CPL_BEGIN_DECLS
 
@@ -38,6 +40,8 @@ extern const char *const fors_bias_author;
 extern const char *const fors_bias_email;
 extern const char *const fors_bias_description;
 void fors_bias_define_parameters(cpl_parameterlist *parameters);
+fors_image *
+fors_bias_stack(const fors_image_list *images, const stack_method *sm);
 void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters);
 
 CPL_END_DECLS
