@@ -23,13 +23,36 @@
 #include <memory>
 #include "fiera_config.h"
 
-std::auto_ptr<mosca::fiera_config> fors_ccd_settings_equal(const cpl_frameset * fset);
+namespace fors 
+{
 
-void fors_update_ccd_ron(mosca::ccd_config ccd_config, 
+/*
+ * This class represents the CCD configuration of the FIERA controlled detectors
+ * It inherits from mosca::fiera_config but it modifies the pre/overscan regions
+ * in some cases due to bad performance of some detectors.
+ * Ticket PIPE-6125 contains the background about this. 
+ */
+class fiera_config : public mosca::fiera_config
+{
+public:
+    
+    fiera_config(const cpl_propertylist * header);
+    
+    fiera_config();
+
+    virtual ~fiera_config();
+};
+
+std::auto_ptr<fors::fiera_config> ccd_settings_equal(const cpl_frameset * fset);
+
+void update_ccd_ron(mosca::ccd_config ccd_config, 
                          cpl_propertylist * master_bias_header);
 
-std::auto_ptr<mosca::fiera_config>  fors_ccd_config_read
+std::auto_ptr<fors::fiera_config>  ccd_config_read
 (const cpl_frame * target, const cpl_frame * bias_frame);
 
+
+} /* namespace fors */
+
 #endif /* FORS_CCD_CONFIG_H */
 
