@@ -35,15 +35,13 @@
 //is taken from the header as ESO DET OUT? GAIN, for instance, also per 
 //readout port.
 void fors_image_variance_from_detmodel(fors_image * image,
-                                       const mosca::ccd_config& ccd_config)
+                                       const mosca::ccd_config& ccd_config,
+                                       std::vector<double>& overscan_level)
 {
-
-
-    //Check that the overscan has not been trimmed:
-    if(cpl_image_get_size_x(image->data) != ccd_config.whole_image_npix_x() ||
-       cpl_image_get_size_y(image->data) != ccd_config.whole_image_npix_y())
-        throw std::invalid_argument("Pre/Overscan has already been trimmed. "
-                                    "Cannot compute variance for detector");
+    //Check the number of overscan level is consistent with number of ports
+    if(ccd_config.nports() != overscan_level.size())
+        throw std::invalid_argument("Mismatch between overscan levels and ports");
+    
     
     //Images which contain the model parameters per port
     cpl_size im_nx = fors_image_get_size_x(image);
@@ -55,24 +53,10 @@ void fors_image_variance_from_detmodel(fors_image * image,
     //Loop on each port:
     for(size_t iport = 0; iport < ccd_config.nports(); iport++)
     {
-        mosca::rect_region ps_reg = 
-                ccd_config.prescan_region(iport).coord_0to1();
-        if(ps_reg.is_empty())
-        {
-            cpl_image_delete(ron_sq_im);
-            cpl_image_delete(gain_im);
-            cpl_image_delete(os_im);
-            throw std::invalid_argument("Prescan area is empty. Cannot compute "
-                    "detector noise model");
-        }
-        
         double ron  = ccd_config.computed_ron(iport);
         
         double gain = ccd_config.nominal_gain(iport);
         
-        double os_level = cpl_image_get_median_window
-          (image->data, ps_reg.llx(), ps_reg.lly(), ps_reg.urx(), ps_reg.ury());
-
         mosca::rect_region port_reg = 
                         ccd_config.port_region(iport).coord_0to1();
 
@@ -82,7 +66,7 @@ void fors_image_variance_from_detmodel(fors_image * image,
             {
                 cpl_image_set(ron_sq_im, ix, iy, ron * ron);
                 cpl_image_set(gain_im, ix, iy, gain);
-                cpl_image_set(os_im, ix, iy, os_level);
+                cpl_image_set(os_im, ix, iy, overscan_level[iport]);
             }
     }
     
@@ -118,14 +102,16 @@ void fors_image_variance_from_detmodel(fors_image * image,
 }
 
 void fors_image_variance_from_detmodel(fors_image_list * ima_list,
-                                       const mosca::ccd_config& ccd_config)
+                                       const mosca::ccd_config& ccd_config,
+                                       std::vector<double>& overscan_level)
 {
     int nima = fors_image_list_size(ima_list);
 
     fors_image * target_ima = fors_image_list_first(ima_list);
     for(int ima = 0; ima < nima; ++ima)
     {
-        fors_image_variance_from_detmodel(target_ima, ccd_config);
+        fors_image_variance_from_detmodel(target_ima, ccd_config, 
+                                          overscan_level);
         target_ima = fors_image_list_next(ima_list);
     }    
 
