@@ -24,9 +24,11 @@
 #include "ccd_config.h"
 
 void fors_image_variance_from_detmodel(fors_image * image,
-                                       const mosca::ccd_config& ccd_config);
+                                       const mosca::ccd_config& ccd_config,
+                                       std::vector<double>& overscan_level);
 
 void fors_image_variance_from_detmodel(fors_image_list * ima_list,
-                                       const mosca::ccd_config& ccd_config);
+                                       const mosca::ccd_config& ccd_config,
+                                       std::vector<double>& overscan_level);
 
 #endif /* FORS_DETMODEL_H_ */
