@@ -80,6 +80,16 @@ static char *strlower(char *s)
 
 }
 
+static const cpl_frame* get_next_const_and_advance(cpl_frameset_iterator* it)
+{
+	const cpl_frame* to_ret = cpl_frameset_iterator_get_const(it);
+
+	if(to_ret)
+		cpl_frameset_iterator_advance(it, 1);
+
+	return to_ret;
+}
+
 /*----------------------------------------------------------------------------*/
 /*----------------------------------------------------------------------------*/
 char *dfs_generate_filename(const char *category)
@@ -263,8 +273,7 @@ fors_dfs_set_groups(cpl_frameset * set)
     
     for (i_frame = 0; i_frame < cpl_frameset_get_size(set); ++i_frame) {
 
-        f = cpl_frameset_get_position_const(set, i_frame);
-
+        f = cpl_frameset_get_position(set, i_frame);
         const char *tag = cpl_frame_get_tag(f);
 
         if (tag != NULL) {
@@ -393,16 +402,16 @@ fors_dfs_pipeline_version(const cpl_propertylist *header,
  *
  * @return The parameter value
  *
- * This function is just a wrapper to the basic CPL function
- * @c cpl_parameter_get_int(), but if a @em defaults table is 
- * passed then the parameter value is searched in that table.
- * If it is found, the parameter value will be modified also
+ * This function works exactly as @c cpl_parameter_get_int()
+ * in the following cases:
+ * 1) @em defaults table is not specified;
+ * 2) @em parlist contains non-default values.
+ * Otherwise, @em name is also searched in @em defaults table.
+ * If @em name is found, the parameter value will be modified also
  * on the input parameter list before being returned, so that
  * it would appear on the recipe products headers. If the
  * parameter is not found, then the parameter value is simply
- * read from the input parameter list. If a @em defaults table
- * is not specified, then this function works exactly as the
- * function @c cpl_parameter_get_int().
+ * read from the input parameter list.
  */
 /*----------------------------------------------------------------------------*/
 int dfs_get_parameter_int(cpl_parameterlist *parlist, const char *name,
@@ -443,7 +452,6 @@ int dfs_get_parameter_int(cpl_parameterlist *parlist, const char *name,
 
     alias = cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI);
 
-//    if (defaults && cpl_parameter_get_default_flag(param) == 0) {
     if (defaults && 
         cpl_parameter_get_default_int(param) == cpl_parameter_get_int(param)) {
     
@@ -488,16 +496,16 @@ int dfs_get_parameter_int(cpl_parameterlist *parlist, const char *name,
  *
  * @return The parameter value
  *
- * This function is just a wrapper to the basic CPL function
- * @c cpl_parameter_get_double(), but if a @em defaults table is 
- * passed then the parameter value is searched in that table.
- * If it is found, the parameter value will be modified also
+ * This function works exactly as @c cpl_parameter_get_double()
+ * in the following cases:
+ * 1) @em defaults table is not specified;
+ * 2) @em parlist contains non-default values.
+ * Otherwise, @em name is also searched in @em defaults table.
+ * If @em name is found, the parameter value will be modified also
  * on the input parameter list before being returned, so that
  * it would appear on the recipe products headers. If the
  * parameter is not found, then the parameter value is simply
- * read from the input parameter list. If a @em defaults table
- * is not specified, then this function works exactly as the
- * function @c cpl_parameter_get_double().
+ * read from the input parameter list.
  */
 /*----------------------------------------------------------------------------*/
 double dfs_get_parameter_double(cpl_parameterlist *parlist, 
@@ -538,7 +546,6 @@ double dfs_get_parameter_double(cpl_parameterlist *parlist,
 
     alias = cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI);
 
-//    if (defaults && cpl_parameter_get_default_flag(param) == 0) {
     if (defaults && 
         cpl_parameter_get_default_double(param) == 
         cpl_parameter_get_double(param)) {
@@ -584,17 +591,18 @@ double dfs_get_parameter_double(cpl_parameterlist *parlist,
  *
  * @return The parameter value
  *
- * This function is just a wrapper to the basic CPL function
- * @c cpl_parameter_get_string(), but if a @em defaults table is 
- * passed then the parameter value is searched in that table.
- * If it is found, the parameter value will be modified also
+ * This function works exactly as @c cpl_parameter_get_string()
+ * in the following cases:
+ * 1) @em defaults table is not specified;
+ * 2) @em parlist contains non-default values.
+ * Otherwise, @em name is also searched in @em defaults table.
+ * If @em name is found, the parameter value will be modified also
  * on the input parameter list before being returned, so that
  * it would appear on the recipe products headers. If the
  * parameter is not found, then the parameter value is simply
- * read from the input parameter list. If a @em defaults table
- * is not specified, then this function works exactly as the
- * function @c cpl_parameter_get_string().
+ * read from the input parameter list.
  */
+
 /*----------------------------------------------------------------------------*/
 const char *dfs_get_parameter_string(cpl_parameterlist *parlist, 
                                      const char *name, 
@@ -635,7 +643,6 @@ const char *dfs_get_parameter_string(cpl_parameterlist *parlist,
 
     alias = cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI);
 
-//    if (defaults && cpl_parameter_get_default_flag(param) == 0) {
     if (defaults && 
         strcmp(cpl_parameter_get_default_string(param), 
                cpl_parameter_get_string(param)) == 0) {
@@ -681,16 +688,16 @@ const char *dfs_get_parameter_string(cpl_parameterlist *parlist,
  *
  * @return The parameter value
  *
- * This function is just a wrapper to the basic CPL function
- * @c cpl_parameter_get_bool(), but if a @em defaults table is 
- * passed then the parameter value is searched in that table.
- * If it is found, the parameter value will be modified also
+ * This function works exactly as @c cpl_parameter_get_bool()
+ * in the following cases:
+ * 1) @em defaults table is not specified;
+ * 2) @em parlist contains non-default values.
+ * Otherwise, @em name is also searched in @em defaults table.
+ * If @em name is found, the parameter value will be modified also
  * on the input parameter list before being returned, so that
  * it would appear on the recipe products headers. If the
  * parameter is not found, then the parameter value is simply
- * read from the input parameter list. If a @em defaults table
- * is not specified, then this function works exactly as the
- * function @c cpl_parameter_get_bool().
+ * read from the input parameter list.
  */
 /*----------------------------------------------------------------------------*/
 int dfs_get_parameter_bool(cpl_parameterlist *parlist, const char *name,
@@ -732,7 +739,6 @@ int dfs_get_parameter_bool(cpl_parameterlist *parlist, const char *name,
 
     alias = cpl_parameter_get_alias(param, CPL_PARAMETER_MODE_CLI);
 
-//    if (defaults && cpl_parameter_get_default_flag(param) == 0) {
     if (defaults && 
         cpl_parameter_get_default_bool(param) == 
         cpl_parameter_get_bool(param)) {
@@ -1677,16 +1683,16 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
 {
     const char       *func = "dfs_equal_keyword";
 
-    cpl_frame        *frame;
-    cpl_propertylist *reference;
-    cpl_type          rtype;
-    cpl_type          type;
-    const char       *rstring;
-    const char       *string;
-    int               rintero;
-    int               intero;
-    int               found;
-
+    cpl_propertylist      *reference;
+    cpl_type               rtype;
+    cpl_type               type;
+    char                  *rstring = NULL;
+    const char            *string;
+    int                    rintero;
+    int                    intero;
+    int                    found;
+    cpl_frameset_iterator *it;
+    const cpl_frame       *frame;
 
     if (frameset == NULL || keyword == NULL) {
         cpl_error_set(func, CPL_ERROR_NULL_INPUT);
@@ -1697,17 +1703,16 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
         cpl_error_set(func, CPL_ERROR_DATA_NOT_FOUND);
         return 0;
     }
-        
-    frame = cpl_frameset_get_first(frameset);
+
+    it =  cpl_frameset_iterator_new(frameset);
 
     found = 0;
 
-    while (frame) {
+    while ((frame = get_next_const_and_advance(it)) != NULL){
 
-        reference = cpl_propertylist_load(cpl_frame_get_filename(frame), 0);
+    	reference = cpl_propertylist_load(cpl_frame_get_filename(frame), 0);
         if (cpl_error_get_code() == CPL_ERROR_BAD_FILE_FORMAT) {
             cpl_error_reset();
-            frame = cpl_frameset_get_next(frameset);
             continue;
         }
 
@@ -1730,26 +1735,28 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
             }
 
             cpl_propertylist_delete(reference);
+            cpl_frameset_iterator_delete(it);
+			cpl_free(rstring);
             return 0;
         }
 
         cpl_propertylist_delete(reference);
-
-        frame = cpl_frameset_get_next(frameset);
     }
 
+    cpl_frameset_iterator_delete(it);
 
     if (!found)
-        return 1;
+    {
+    	cpl_free(rstring);
+    	return 1;
+    }
+    it =  cpl_frameset_iterator_new(frameset);
 
-    frame = cpl_frameset_get_first(frameset);
-
-    while (frame) {
+    while ((frame = get_next_const_and_advance(it)) != NULL){
 
         reference = cpl_propertylist_load(cpl_frame_get_filename(frame), 0);
         if (cpl_error_get_code() == CPL_ERROR_BAD_FILE_FORMAT) {
             cpl_error_reset();
-            frame = cpl_frameset_get_next(frameset);
             continue;
         }
 
@@ -1759,6 +1766,8 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
 
             if (rtype != type) {
                 cpl_propertylist_delete(reference);
+                cpl_frameset_iterator_delete(it);
+                cpl_free(rstring);
                 return 0;
             }
 
@@ -1767,6 +1776,8 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
                                                      keyword);
                 if (strncmp(rstring, string, 15)) {
                     cpl_propertylist_delete(reference);
+                    cpl_frameset_iterator_delete(it);
+                    cpl_free(rstring);
                     return 0;
                 }
             }
@@ -1775,18 +1786,18 @@ int dfs_equal_keyword(cpl_frameset *frameset, const char *keyword)
                 intero = cpl_propertylist_get_int(reference, keyword);
                 if (rintero - intero) {
                     cpl_propertylist_delete(reference);
+                    cpl_frameset_iterator_delete(it);
+                    cpl_free(rstring);
                     return 0;
                 }
             }
         }
 
         cpl_propertylist_delete(reference);
-
-        frame = cpl_frameset_get_next(frameset);
     }
 
-    if (rtype == CPL_TYPE_STRING)
-        cpl_free((void *)rstring);
+    cpl_frameset_iterator_delete(it);
+	cpl_free(rstring);
 
     return 1;
 
