@@ -839,6 +839,20 @@ extract_sex(                                const fors_image *image,
     if (extracted_sources != NULL) {
         *extracted_sources = cpl_table_duplicate(out);
     }
+
+    /* Remove the temporary files needed by sextractor */
+    int status = unlink(filename_data);
+    status +=    unlink(filename_sigma);
+    if (vignetted) 
+    {
+        status += unlink(filename_sigma_full);
+        status += unlink(filename_data_full);
+    }
+    status += unlink(filename_cat);
+    status += unlink(filename_bkg);
+ 
+    assure( status == 0, return NULL,
+            "Problem removing temporary files");
     
     cleanup;
     return stars;
