@@ -553,6 +553,8 @@ std::vector<float> fors::flat_normaliser::get_wave_profiles_norm
     for(size_t i = 0; i < m_wave_profiles_norm.size(); ++i)
     {
         float scale = mflat_exptime * slit_widths[i] * slit_lengths[i];
+        if(scale == 0 )
+            scale = 1;  //In some cases the length has been detected as 0.
         wave_profiles_norm_scaled.push_back(m_wave_profiles_norm[i] / scale);
     }
     
