@@ -279,7 +279,6 @@ fors_image_load_list_const(const cpl_frameset *frames)
 #undef cleanup
 #define cleanup \
 do { \
-    cpl_image_delete(temp); \
 } while (0)
 /**
  * @brief    Load image
@@ -294,7 +293,6 @@ fors_image_load(const cpl_frame *frame)
     fors_image *image           = NULL;
     cpl_image *data             = NULL;
     cpl_image *variance         = NULL;
-    cpl_image *temp             = NULL;
     const char *filename;
     int extension= 0;
     const int plane = 0;
@@ -315,7 +313,7 @@ fors_image_load(const cpl_frame *frame)
     data = cpl_image_load(filename, 
                           FORS_IMAGE_TYPE, plane, extension);
     
-    assure( !cpl_error_get_code(), return image, 
+    assure( data != NULL, return image, 
             "Could not load image from %s extension %d", 
             filename, extension);
 
@@ -338,17 +336,17 @@ fors_image_load(const cpl_frame *frame)
         variance = cpl_image_load(filename, 
                                   FORS_IMAGE_TYPE, plane, extension);
         
-        assure( !cpl_error_get_code(), return image, 
+        assure( variance != NULL, return image, 
                 "Could not load image from %s extension %d", 
                 filename, extension);
 
         cpl_image_power(variance, 2);
 
-        assure( cpl_image_get_min(variance) >= 0, return image,
+        assure( cpl_image_get_min(variance) >= 0, 
+                cpl_image_delete(variance); return image,
                 "Illegal minimum variance: %g",
                 cpl_image_get_min(variance));
 
-        cpl_image_delete(temp); temp = NULL;
     }
     
     image = fors_image_new(data, variance);
@@ -375,6 +373,7 @@ do { \
  */
 void
 fors_image_save(const fors_image *image, const cpl_propertylist *header,
+                const cpl_propertylist *err_header,
                 const char *filename)
 {
     cpl_propertylist *extension_header = NULL;
@@ -391,7 +390,10 @@ fors_image_save(const fors_image *image, const cpl_propertylist *header,
     
     sigma = cpl_image_power_create(image->variance, 0.5);
     /* This would probably be faster if sqrt() is used rather than pow */
-    extension_header = cpl_propertylist_new();
+    if(err_header != NULL)
+        extension_header = cpl_propertylist_duplicate(err_header);
+    else
+        extension_header = cpl_propertylist_new();
     cpl_propertylist_append_string(extension_header, 
                                    "EXTNAME", "IMAGE.ERR");
 
@@ -1776,6 +1778,7 @@ hdrl_imagelist * fors_image_list_to_hdrl(const fors_image_list * imalist)
         hdrl_imagelist_set(images_hdrl, ima_hdrl, 
                            hdrl_imagelist_get_size(images_hdrl));
         target = fors_image_list_next_const(imalist);
+        cpl_image_delete(ima_error);
     }
     
     return images_hdrl;
@@ -1785,7 +1788,7 @@ fors_image * fors_image_from_hdrl(const hdrl_image * image)
 {
     const cpl_image * data = hdrl_image_get_image_const(image);
     cpl_image * variance = cpl_image_power_create
-            (hdrl_image_get_image_const(image), 2);
+            (hdrl_image_get_error_const(image), 2);
     fors_image * ima = fors_image_new(cpl_image_duplicate(data), variance);
     return ima;
 }
