@@ -92,7 +92,7 @@ fors_image_load_list_const(const cpl_frameset *frames);
 
 void
 fors_image_save(const fors_image *image, const cpl_propertylist *header,
-		const char *filename);
+                const cpl_propertylist *err_header, const char *filename);
 
 void
 fors_image_save_sex(const fors_image *image, const cpl_propertylist *header,
