@@ -44,6 +44,7 @@
 #include "fors_ccd_config.h"
 #include "fors_detmodel.h"
 #include <fors_subtract_bias.h>
+#include "fors_bpm.h"
 
 #include <cpl.h>
 #include <math.h>
@@ -257,7 +258,6 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
     fors::update_ccd_ron(ccd_config, master_bias_header);
-    cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
 
@@ -266,20 +266,41 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     assure( !cpl_error_get_code(), return, 
             "Could not load master bias");
 
-    /* Load raw frames, subtract bias */
+    /* Load raw frames */
     fors_image * sci_raw = 
             fors_image_load(cpl_frameset_get_position(sci_frame, 0));
     assure( !cpl_error_get_code(), return, "Could not load science frames");
 
+    /* Check that the overscan configuration is consistent */
+    bool perform_preoverscan = !fors_is_preoverscan_empty(ccd_config);
+
+    assure(perform_preoverscan == 
+           fors_is_master_bias_preoverscan_corrected(master_bias_header),
+           return, "Master bias overscan configuration doesn't match science");
+    cpl_propertylist_delete(master_bias_header);
+    
     /* Create variance */
-    fors_image_variance_from_detmodel(sci_raw, ccd_config);
+    std::vector<double> overscan_levels; 
+    if(perform_preoverscan)
+        overscan_levels = fors_get_bias_levels_from_overscan(sci_raw, ccd_config);
+    else
+        overscan_levels = fors_get_bias_levels_from_mbias(master_bias, ccd_config);
+    fors_image_variance_from_detmodel(sci_raw, ccd_config, overscan_levels);
     
     /*Subtract overscan */
-    sci = fors_subtract_prescan(sci_raw, ccd_config);
+    if(perform_preoverscan)
+        sci = fors_subtract_prescan(sci_raw, ccd_config);
+    else 
+    {
+        sci = fors_image_duplicate(sci_raw); 
+        //The rest of the recipe assumes that the images carry a bpm.
+        fors_bpm_image_make_explicit(sci); 
+    }
     assure( !cpl_error_get_code(), return, "Could not subtract overscan");
 
     /* Trim pre/overscan */
-    fors_trimm_preoverscan(sci, ccd_config);
+    if(perform_preoverscan)
+        fors_trimm_preoverscan(sci, ccd_config);
     fors_image_delete(&sci_raw);
     assure( !cpl_error_get_code(), return, "Could not trimm overscan");
 
