@@ -42,7 +42,8 @@ cpl_table * fors_compute_response
  const std::vector<double>& ignored_waves,
  const std::vector<std::pair<double, double> >& ignored_wave_ranges,
  int nknots, int degree, cpl_table *& response_interp,
- double& flat_sed_norm_factor)
+ double& flat_sed_norm_factor,
+ const fors::detected_slits& det_slits)
 {
 
     cpl_image *spectrum       = NULL; // Extracted standard star spectrum
@@ -144,7 +145,7 @@ cpl_table * fors_compute_response
                         cpl_image_get(spectrum_sedcorr, i_pix+1, 1, &null) / profile_val);
         }
         std::ostringstream norm_key;
-        norm_key<< "ESO QC FLAT SED"<<obj_slit+1<<" NORM";
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[obj_slit].slit_id()<<" NORM";
         flat_sed_norm_factor = 
           cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         if(cpl_error_get_code() == CPL_ERROR_DATA_NOT_FOUND)
@@ -322,11 +323,68 @@ cpl_table * fors_compute_response
     return response_table;
 }
 
+void fors_science_correct_flat_sed
+(cpl_image *spectra,  cpl_table *objects,
+ cpl_image * mapped_flat_sed,
+ cpl_propertylist * flat_sed_header,
+ cpl_propertylist * specphot_header,
+ const fors::detected_slits& det_slits)
+{
+
+    cpl_size nx = cpl_image_get_size_x(spectra);
+    cpl_size nslits = cpl_table_get_nrow(objects);
+    int   maxobjects = 1;
+    char  name[MAX_COLNAME];
+    int   null;
+    snprintf(name, MAX_COLNAME, "object_%d", maxobjects);
+    while (cpl_table_has_column(objects, name)) {
+        maxobjects++;
+        snprintf(name, MAX_COLNAME, "object_%d", maxobjects);
+    }
+    maxobjects--;
+    //TODO: Move it away from here. It is also repeated in the science photometric correction
+    for (cpl_size i_slit = 0; i_slit < nslits; i_slit++) {
+        /* Get the proper normalisation factor. The flat sed has to be
+         * normalised by the same normalisation factor applied in the
+         * creation of specphot.
+         * So the original factor applied to the flat sed has to be removed 
+         * and then apply the one in the specphot */
+        std::ostringstream norm_key;
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[i_slit].slit_id()<<" NORM";
+        double flat_sed_norm_orig =
+            cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
+        double specphot_flat_sed_norm = 
+            cpl_propertylist_get_double(specphot_header, "ESO QC RESP FLAT_SED_NORM");
+        double flat_sed_final_norm_factor = specphot_flat_sed_norm / flat_sed_norm_orig ;
+
+        for (int i_obj = 1; i_obj <= maxobjects; i_obj++) {
+            snprintf(name, MAX_COLNAME, "row_%d", i_obj);
+            if (cpl_table_is_valid(objects, name, i_slit))
+            {
+               int null;
+               int idx_obj = 
+                   cpl_table_get_int(objects, name, i_slit, &null);
+                /* Divide the target spectrum by the corresponding slit profile */
+                for (cpl_size i_pix = 0; i_pix < nx; i_pix++)
+                {
+                    double profile_val  = cpl_image_get(mapped_flat_sed, i_pix+1, i_slit+1, &null);
+                    if(profile_val != 0)
+                        cpl_image_set(spectra, i_pix+1, idx_obj+1, 
+                                cpl_image_get(spectra, i_pix+1, idx_obj+1, &null) / profile_val *
+                                flat_sed_final_norm_factor);
+                }
+            }
+        }
+    }
+}
+
+
 void fors_science_correct_flat_sed_mapped
 (cpl_image *mapped_image,  cpl_table *objects,
  cpl_image * mapped_flat_sed,
  cpl_propertylist * flat_sed_header,
- cpl_propertylist * specphot_header)
+ cpl_propertylist * specphot_header,
+ const fors::detected_slits& det_slits)
 {
 
     cpl_size nx = cpl_image_get_size_x(mapped_image);
@@ -340,7 +398,7 @@ void fors_science_correct_flat_sed_mapped
          * and then aaply the one in the specphot */
         int null;
         std::ostringstream norm_key;
-        norm_key<< "ESO QC FLAT SED"<<i_slit+1<<" NORM";
+        norm_key<< "ESO QC FLAT SED_"<<det_slits[i_slit].slit_id()<<" NORM";
         double flat_sed_norm_orig =
             cpl_propertylist_get_double(flat_sed_header, norm_key.str().c_str());
         double specphot_flat_sed_norm = 
