@@ -41,6 +41,7 @@
 #include "fors_overscan.h"
 #include "fors_subtract_bias.h"
 #include "fors_detmodel.h"
+#include "fors_bpm.h"
 
 
 #include <cpl.h>
@@ -350,7 +351,6 @@ void fors_zeropoint(cpl_frameset *frames, const cpl_parameterlist *parameters)
        cpl_propertylist_load(cpl_frame_get_filename(
                cpl_frameset_get_position(master_bias_frame, 0)), 0);
     fors::update_ccd_ron(ccd_config, master_bias_header);
-    cpl_propertylist_delete(master_bias_header);
     assure( !cpl_error_get_code(), return, "Could not get RON from master bias"
             " (missing QC DET OUT? RON keywords)");
 
@@ -369,12 +369,40 @@ void fors_zeropoint(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Load raw frames, subtract overscan and bias */
     fors_image * std_raw = 
         fors_image_load(cpl_frameset_get_position(std_frame, 0));
+    
+    /* Check that the overscan configuration is consistent */
+    bool perform_preoverscan = !fors_is_preoverscan_empty(ccd_config);
+
+    assure(perform_preoverscan == 
+           fors_is_master_bias_preoverscan_corrected(master_bias_header),
+           return, "Master bias overscan configuration doesn't match science");
+    cpl_propertylist_delete(master_bias_header);
+
     /* Create variance map */
-    fors_image_variance_from_detmodel(std_raw, ccd_config);
+    std::vector<double> overscan_levels; 
+    if(perform_preoverscan)
+        overscan_levels = fors_get_bias_levels_from_overscan(std_raw, ccd_config);
+    else
+        overscan_levels = fors_get_bias_levels_from_mbias(master_bias, ccd_config);
+    fors_image_variance_from_detmodel(std_raw, ccd_config, overscan_levels);
+
     /*Subtract overscan */
-    std = fors_subtract_prescan(std_raw, ccd_config);
-    fors_trimm_preoverscan(std, ccd_config);
+    if(perform_preoverscan)
+        std = fors_subtract_prescan(std_raw, ccd_config);
+    else 
+    {
+        std = fors_image_duplicate(std_raw); 
+        //The rest of the recipe assumes that the images carry a bpm.
+        fors_bpm_image_make_explicit(std); 
+    }
+    assure( !cpl_error_get_code(), return, "Could not subtract overscan");
+
+    /* Trim pre/overscan */
+    if(perform_preoverscan)
+        fors_trimm_preoverscan(std, ccd_config);
     fors_image_delete(&std_raw);
+    assure( !cpl_error_get_code(), return, "Could not trimm overscan");
+
     /* Subtract bias */
     fors_subtract_bias(std, master_bias);
     assure( !cpl_error_get_code(), return, "Could not load standard image");
