@@ -38,12 +38,15 @@
 
 #include <cpl.h>
 
+#include <fs_test.h>
+
 /**
  * @defgroup fors_bias_test  test of master bias recipe
  */
 
 /**@{*/
 
+
 #undef cleanup
 #define cleanup \
 do { \
@@ -53,6 +56,8 @@ do { \
     fors_image_delete(&raw_bias); \
     fors_image_delete(&master_bias); \
     cpl_propertylist_delete(product_header); \
+    delete_test_files(bias_filename);\
+    delete_test_files_from_tag(product_tags);\
 } while(0)
 
 /**
@@ -78,7 +83,8 @@ test_bias(void)
                                    "bias_3.fits",
                                    "bias_4.fits",
                                    "bias_5.fits"};
-    
+    const char *product_tags[] = {MASTER_BIAS};
+
     {
         unsigned i;
         
@@ -103,7 +109,6 @@ test_bias(void)
             "Execution error");
 
     /* Test existence of QC + products */
-    const char *const product_tags[] = {MASTER_BIAS};
     const char *const qc[] = 
         {"QC BIAS STRUCT", "QC BIAS LEVEL", "QC RON", "QC BIAS FPN",
          "QC MBIAS LEVEL",
@@ -168,6 +173,7 @@ test_bias(void)
     return;
 }
 
+
 /**
  * @brief   Test of image module
  */
