@@ -38,6 +38,8 @@
 
 #include <cpl.h>
 
+#include <fs_test.h>
+
 /**
  * @defgroup fors_dark_test  test of master dark recipe
  */
@@ -53,6 +55,9 @@ do { \
     fors_image_delete(&master_dark); \
     fors_image_delete(&master_bias); \
     fors_setting_delete(&setting); \
+    delete_test_files(dark_filename);\
+    delete_test_file(dark_master_filename);\
+    delete_test_file("master_dark.fits");\
 } while(0)
 
 /**
@@ -76,6 +81,7 @@ test_dark(void)
     const char *dark_filename[] = {"dark_1.fits",
                                    "dark_2.fits",
                                    "dark_3.fits"};
+    const char* dark_master_filename = "dark_master_bias.fits";
 
     {
         unsigned i;
@@ -90,7 +96,7 @@ test_dark(void)
     setting = fors_setting_new(cpl_frameset_get_position(frames, 0));
 
     cpl_frameset_insert(frames, 
-                        create_master_bias("dark_master_bias.fits", 
+                        create_master_bias(dark_master_filename,
                                     MASTER_BIAS, CPL_FRAME_GROUP_CALIB));
     
     fors_dark_define_parameters(parameters);
