@@ -33,6 +33,8 @@
 #include <fors_dfs.h>
 #include <fors_utils.h>
 
+#include <fs_test.h>
+
 #include <test_simulate.h>
 #include <test.h>
 
@@ -48,6 +50,12 @@
 do { \
     cpl_frameset_delete(frames); \
     cpl_parameterlist_delete(parameters); \
+    delete_test_file(img_std_name);\
+    delete_test_file(img_master_name);\
+    delete_test_file(img_sky_name);\
+    delete_test_file(img_cat_name);\
+    delete_test_file(tab_name);\
+    delete_test_files_from_tag(product_tags);\
 } while(0)
 
 /**
@@ -61,22 +69,35 @@ test_img_science(void)
     cpl_parameterlist *parameters = cpl_parameterlist_new();
     cpl_parameter     *p          = NULL;
     double exptime = 1.0;
+
+    const char* img_std_name = "img_science_standard_img.fits";
+    const char* img_master_name = "img_science_master_bias.fits";
+    const char* img_sky_name = "img_science_master_sky_flat.fits";
+    const char* img_cat_name = "img_science_std_cat.fits";
+    const char* tab_name = "img_science_phot_table.fits";
+
+    /* Test existence of QC + products */
+    const char *product_tags[] = {SOURCES_SCI,
+                                        SCIENCE_REDUCED_IMG,
+                                        PHOTOMETRY_TABLE,
+                                        PHOT_BACKGROUND_SCI_IMG};
+
     /* Products */
     
     /* Simulate data */
-    cpl_frameset_insert(frames, create_standard("img_science_standard_img.fits",
+    cpl_frameset_insert(frames, create_standard(img_std_name,
                                                 SCIENCE_IMG,
                                                 CPL_FRAME_GROUP_RAW));
-    cpl_frameset_insert(frames, create_master_bias("img_science_master_bias.fits",
+    cpl_frameset_insert(frames, create_master_bias(img_master_name,
                                             MASTER_BIAS,
                                             CPL_FRAME_GROUP_CALIB));
-    cpl_frameset_insert(frames, create_master_sky_flat("img_science_master_sky_flat.fits",
+    cpl_frameset_insert(frames, create_master_sky_flat(img_sky_name,
                                                 MASTER_SKY_FLAT_IMG,
                                                 CPL_FRAME_GROUP_CALIB, exptime));
-    cpl_frameset_insert(frames, create_std_cat("img_science_std_cat.fits",
+    cpl_frameset_insert(frames, create_std_cat(img_cat_name,
                                                FLX_STD_IMG,
                                                CPL_FRAME_GROUP_CALIB));
-    cpl_frameset_insert(frames, create_phot_table("img_science_phot_table.fits",
+    cpl_frameset_insert(frames, create_phot_table(tab_name,
                                                   PHOT_TABLE,
                                                   CPL_FRAME_GROUP_CALIB));
     
@@ -101,11 +122,6 @@ test_img_science(void)
 
     fors_img_science(frames, parameters);
 
-    /* Test existence of QC + products */
-    const char *const product_tags[] = {SOURCES_SCI, 
-                                        SCIENCE_REDUCED_IMG, 
-                                        PHOTOMETRY_TABLE,
-                                        PHOT_BACKGROUND_SCI_IMG};
     const char *main_product = SCIENCE_REDUCED_IMG;
 
     const char *const qc[] = 
