@@ -252,7 +252,7 @@ create_bias(const char *filename, const char *tag, cpl_frame_group group)
     }
     
     bias = fors_image_new(data, variance);
-    fors_image_save(bias, header, filename);
+    fors_image_save(bias, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL,
             "Saving bias to %s failed", filename );
@@ -297,7 +297,7 @@ create_master_bias(const char *filename, const char *tag, cpl_frame_group group)
     }
     
     bias = fors_image_new(data, variance);
-    fors_image_save(bias, header, filename);
+    fors_image_save(bias, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL,
             "Saving master bias to %s failed", filename );
@@ -360,7 +360,7 @@ create_dark(const char *filename, const char *tag, cpl_frame_group group)
     }
     
     dark = fors_image_new(data, variance);
-    fors_image_save(dark, header, filename);
+    fors_image_save(dark, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL, 
             "Saving dark to %s failed", filename );
@@ -424,7 +424,7 @@ create_screen_flat(const char *filename, const char *tag, cpl_frame_group group)
     }
     
     sflat = fors_image_new(data, variance);
-    fors_image_save(sflat, header, filename);
+    fors_image_save(sflat, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL, 
             "Saving screen flat to %s failed", filename );
@@ -490,7 +490,7 @@ create_sky_flat(const char *filename, const char *tag, cpl_frame_group group,
     }
     
     sflat = fors_image_new(data, variance);
-    fors_image_save(sflat, header, filename);
+    fors_image_save(sflat, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL, 
             "Saving sky flat to %s failed", filename );
@@ -543,7 +543,7 @@ create_master_sky_flat(const char *filename,
     }
     
     sflat = fors_image_new(data, variance);
-    fors_image_save(sflat, header, filename);
+    fors_image_save(sflat, header, NULL, filename);
 
     assure( !cpl_error_get_code(), return NULL, 
             "Saving sky flat to %s failed", filename );
