@@ -37,7 +37,7 @@ BOOST_AUTO_TEST_CASE(fors_marlene_out1_bin2)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/marlene_out1_bin2.fits",0);
+            cpl_propertylist_load(DATADIR "data/marlene_out1_bin2.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -66,7 +66,7 @@ BOOST_AUTO_TEST_CASE(fors_tk2048eb4_1_160_out1_bin1)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out1_bin1.fits",0);
+            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out1_bin1.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -95,7 +95,7 @@ BOOST_AUTO_TEST_CASE(fors_tk2048eb4_1_160_out4_bin1)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out4_bin1.fits",0);
+            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out4_bin1.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -166,7 +166,7 @@ BOOST_AUTO_TEST_CASE(fors_tk2048eb4_1_160_out4_bin2)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out4_bin2.fits",0);
+            cpl_propertylist_load(DATADIR "data/tk2048eb4_1_160_out4_bin2.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -237,7 +237,7 @@ BOOST_AUTO_TEST_CASE(fors_ccid20_14_5_6_out1_bin2)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/ccid20_14_5_6_out1_bin2.fits",0);
+            cpl_propertylist_load(DATADIR "data/ccid20_14_5_6_out1_bin2.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -266,20 +266,20 @@ BOOST_AUTO_TEST_CASE(fors_ccid20_14_5_3_out1_bin2)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/ccid20_14_5_3_out1_bin2.fits",0);
+            cpl_propertylist_load(DATADIR "data/ccid20_14_5_3_out1_bin2.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
     BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
-    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 1029);
     BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 2047);
-    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 1033);
 
     //Check overscan region port 1
     BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 0);
-    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 1029);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
     BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2047);
-    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 1033);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4);
 
     //Check valid pixels region port 1
     BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 0);
@@ -295,7 +295,7 @@ BOOST_AUTO_TEST_CASE(fors_ccid20_14_5_3_out1_bin1)
 {
     cpl_init(CPL_INIT_DEFAULT);
     cpl_propertylist * header = 
-            cpl_propertylist_load(DATADIR "data/ccid20_14_5_3_out1_bin1.fits",0);
+            cpl_propertylist_load(DATADIR "data/ccid20_14_5_3_out1_bin1.fits.gz",0);
     mosca::fiera_config ccd_config(header);
 
     //Check prescan region port 1
@@ -320,6 +320,208 @@ BOOST_AUTO_TEST_CASE(fors_ccid20_14_5_3_out1_bin1)
     cpl_end();
 }
 
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44__ccd_59a)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+            cpl_propertylist_load(DATADIR "data/eev_ccd_44__ccd_59a.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4095);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4095);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 4095);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44__ccd_59b)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+            cpl_propertylist_load(DATADIR "data/eev_ccd_44__ccd_59b.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4095);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4095);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 4095);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44__ccd_60a)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+            cpl_propertylist_load(DATADIR "data/eev_ccd_44__ccd_60a.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4095);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4095);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 4095);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44__ccd_60b)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+            cpl_propertylist_load(DATADIR "data/eev_ccd_44__ccd_60b.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4095);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4095);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 4095);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44_82__david)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+           cpl_propertylist_load(DATADIR "data/eev_ccd_44_82__david.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 2439);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 2439);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 2439);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44_82__tom)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+            cpl_propertylist_load(DATADIR "data/eev_ccd_44_82__tom.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 2439);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 2439);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 2439);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
+
+BOOST_AUTO_TEST_CASE(vimos_eev_ccd_44_82__tom_ny_4096)
+{
+    cpl_init(CPL_INIT_DEFAULT);
+    cpl_propertylist * header = 
+     cpl_propertylist_load(DATADIR "data/eev_ccd_44_82__tom_ny_4096.fits.gz",0);
+    mosca::fiera_config ccd_config(header);
+
+    //Check prescan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).llx(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).urx(), 49);
+    BOOST_CHECK_EQUAL(ccd_config.prescan_region(0).ury(), 4095);
+
+    //Check overscan region port 1
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).llx(), 2098);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).urx(), 2147);
+    BOOST_CHECK_EQUAL(ccd_config.overscan_region(0).ury(), 4095);
+
+    //Check valid pixels region port 1
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).llx(), 50);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).lly(), 0);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).urx(), 2097);
+    BOOST_CHECK_EQUAL(ccd_config.validpix_region(0).ury(), 4095);
+
+    cpl_propertylist_delete(header);
+    cpl_end();
+}
 
 BOOST_AUTO_TEST_SUITE_END()
 
