@@ -60,7 +60,7 @@ static char fors_config_description[] =
 
 #define fors_config_exit(message)             \
 {                                             \
-if (message) cpl_msg_error(recipe, message);  \
+if ((const char *)message != NULL) cpl_msg_error(recipe, message);  \
 cpl_table_delete(table);                      \
 cpl_propertylist_delete(header);              \
 cpl_free(filename);                           \
