@@ -434,7 +434,9 @@ static int fors_extract_objects(cpl_parameterlist *parlist,
     cpl_msg_info(recipe, "Object extraction...");
     cpl_msg_indent_more();
 
-    images = mos_extract_objects(mapped, skymapped, slits,
+    //TODO: Add the real propagated variance here (the second argument)
+    //It should be done like in fors_science  
+    images = mos_extract_objects(mapped, NULL, skymapped, slits,
                                  ext_mode, ron, gain, 1);
 
     cpl_image_delete(mapped); mapped = NULL;
