@@ -495,13 +495,31 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_propertylist * master_bias_header =
            cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
         fors::update_ccd_ron(ccd_config, master_bias_header);
-        cpl_propertylist_delete(master_bias_header);
         if(!cpl_errorstate_is_equal(error_prevstate))
             fors_flat_exit("Could not get RON from master bias"
                     " (missing QC DET OUT? RON keywords)");
         
-        /* Create variances map */
-        fors_image_variance_from_detmodel(flat_raw, ccd_config);
+        /* Check that the overscan configuration is consistent */
+        bool perform_preoverscan = !fors_is_preoverscan_empty(ccd_config);
+        if(perform_preoverscan != 
+           fors_is_master_bias_preoverscan_corrected(master_bias_header))
+        {
+            cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
+                    "Master bias overscan configuration doesn't match science");
+            return NULL;
+        }
+        cpl_propertylist_delete(master_bias_header);
+
+        /* Create arc variances map */
+        std::vector<double> overscan_levels; 
+        if(perform_preoverscan)
+            overscan_levels = fors_get_bias_levels_from_overscan(flat_raw, 
+                                                                 ccd_config);
+        else
+            overscan_levels = fors_get_bias_levels_from_mbias(master_bias, 
+                                                              ccd_config);
+        fors_image_variance_from_detmodel(flat_raw, ccd_config, 
+                                          overscan_levels);
         if(!cpl_errorstate_is_equal(error_prevstate))
             fors_flat_exit("Could not create errors from detector error model");
         
@@ -521,14 +539,25 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_mask_delete(saturated_0);
 
         /* Subtract overscan */
-        fors_image * flat = fors_subtract_prescan(flat_raw, ccd_config);
+        fors_image * flat;
+        if(perform_preoverscan)
+            flat = fors_subtract_prescan(flat_raw, ccd_config);
+        else 
+        {
+            flat = fors_image_duplicate(flat_raw); 
+            //The rest of the recipe assumes that the images carry a bpm.
+            fors_bpm_image_make_explicit(flat); 
+        }
         if(!cpl_errorstate_is_equal(error_prevstate))
             fors_flat_exit("Could not subtract overscan");
 
         /* Trimm pre/overscan */
-        fors_trimm_preoverscan(flat, ccd_config);
-        fors_trimm_preoverscan(non_linear_flat_masks[i_flat], ccd_config);
-        fors_trimm_preoverscan(saturated_flat_masks[i_flat], ccd_config);
+        if(perform_preoverscan)
+        {
+            fors_trimm_preoverscan(flat, ccd_config);
+            fors_trimm_preoverscan(non_linear_flat_masks[i_flat], ccd_config);
+            fors_trimm_preoverscan(saturated_flat_masks[i_flat], ccd_config);
+        }
         fors_image_delete(&flat_raw);
         if(!cpl_errorstate_is_equal(error_prevstate))
             fors_flat_exit("Could not trimm overscan");
