@@ -250,9 +250,7 @@ static int fors_subtract_sky_lss(cpl_parameterlist *parlist,
     const char *mapped_sky_tag;
     int         mxu, mos, lss;
     int         treat_as_lss = 0;
-    int         nslits;
     int         nscience;
-    double     *xpos;
     double      mxpos;
     int         nx, ny;
     int         standard;
