@@ -1,5 +1,6 @@
 # import the needed modules
 try:
+  import matplotlib.gridspec
   import reflex
   import_sucess = True
 
@@ -41,7 +42,7 @@ try:
       self.flat_mscreen    = None
       self.disp_residuals  = None
       self.detected_lines  = None
-      self.excluded_lines  = list()
+      self.mapping_ignored_real = {}
 
       #Read all the products
       frames = dict()
@@ -83,6 +84,10 @@ try:
         if 'SCREEN_FLAT_'+inst_mode in frames :
           self.flat_mscreen  = PlotableRawFlat(frames['SCREEN_FLAT_'+inst_mode],
                                                flat_norm, curv_frame)
+
+      #Update the parameters
+      requested_lines = self.getCurrentParameterHelper('ignore_lines')
+      self.mapping_ignored_real = self.mapIgnoredRealLines(requested_lines)
                   
     # This function creates all the subplots. It is responsible for the plotting 
     # layouts. 
@@ -184,12 +189,14 @@ The residuals should not show any trends.
 Outliers may be tolerated, but at the edges 
 they may indicate a questionable result. 
 Clicking with middle button will add that line 
-to the --ignore_lines recipe parameter."""
+to the --ignore_lines recipe parameter. 
+Clicking on an already excluded line will remove
+it from the list of lines to exclude"""
       self.subplot_line_res_wave.clear()
       self.detected_lines.plotResVsWave(self.subplot_line_res_wave,
                                         title_line_res_wave,
                                         tooltip_line_res_wave,
-                                        self.excluded_lines)
+                                        self.mapping_ignored_real.keys())
 
     def plotLinePositions(self) :
       title_line_x_y   = 'Detected / Identified arc lines'
@@ -257,23 +264,37 @@ the dispersion relation there will be extrapolated."""
       return widgets
 
     def setExcludedLine(self, point) :
-      excluded_line = self.disp_residuals.getClosestLine(point.xdata)
-      if excluded_line in self.excluded_lines :
-        self.excluded_lines.remove(excluded_line)
+      new_excluded_line = self.disp_residuals.getClosestLine(point.xdata)
+      requested_lines = self.getCurrentParameterHelper('ignore_lines')
+      
+      self.mapping_ignored_real = self.mapIgnoredRealLines(requested_lines)
+      if new_excluded_line in self.mapping_ignored_real.keys():
+        del self.mapping_ignored_real[new_excluded_line]
       else :
-        self.excluded_lines.append(excluded_line)
+        self.mapping_ignored_real[new_excluded_line] = '%.4f' % new_excluded_line
+
       self.plotResiduals()
 
       param_value = str()
-      for line in self.excluded_lines :
-        param_value = param_value + '%.4f, ' % line
+      for line in self.mapping_ignored_real.values() :
+        param_value = param_value + line + ','
       if len(param_value) > 1 :
-        param_value = param_value[:-2]
+        param_value = param_value[:-1]
       new_params = list()
       new_params.append(reflex.RecipeParameter('fors_calib','ignore_lines',
                                                value=param_value))
       return new_params
                 
+    def mapIgnoredRealLines(self, ignore_lines) :
+      real_lines_map = {}
+      for ignore_line in ignore_lines.split(',') :
+        if len(ignore_line.strip()) != 0:
+          real_line = self.disp_residuals.getClosestLine(float(ignore_line))
+          real_lines_map[real_line] = ignore_line
+        
+      return real_lines_map
+      
+
     # This function specifies which are the parameters that should be presented
     # in the window to be edited.
     # Note that the parameter has to be also in the in_sop port (otherwise it 
@@ -314,6 +335,9 @@ In this window, the user will interact with the Fors calibration (flat, slit tra
       title = 'Fors Interactive Calibration'
       return title
 
+    def setCurrentParameterHelper(self, helper) :
+        self.getCurrentParameterHelper = helper
+
 except ImportError:
   import_sucess = 'false'
   print "Error importing modules pyfits, wx, matplotlib, numpy"
