@@ -147,11 +147,14 @@ class PlotableMappedScience :
   def loadFromFits(self) :
     #Reading the flat image
     self.mappedscience.readImage()
+    self.crpix1  = self.mappedscience.readKeyword('CRPIX1', 0)
+    self.crval1  = self.mappedscience.readKeyword('CRVAL1', 0)
+    self.cdelt1  = self.mappedscience.readKeyword('CD1_1', 0)
     
     #Reading the object table
     if self.objecttable is not None:
       nslit = self.objecttable.getTableNrows(1)
-      maxobjectperslit = (self.objecttable.getTableNcols(1) - 7 ) / 4
+      maxobjectperslit = (self.objecttable.getTableNcols(1) - 7 ) / 6
       start_extracted_cols = []
       end_extracted_cols = []
       for obj in range(maxobjectperslit):
@@ -174,7 +177,10 @@ class PlotableMappedScience :
       self.nobjects = len(self.ybottom_obj_extract)
 
   def plot(self, subplot, title, tooltip):
-    self.mappedsciencedisp.setLabels('X [pix]', 'Y [pix]')
+    self.mappedsciencedisp.setLabels('Lambda [Ang]', 'Y [pix]')
+    self.mappedsciencedisp.setXLinearWCSAxis(self.crval1, 
+               self.cdelt1, self.crpix1)
+
     self.mappedsciencedisp.display(subplot, title, tooltip, self.mappedscience.image)
     if self.objecttable is not None:
       subplot.autoscale(enable=False)
